==> solr-test-framework-6.0.0-sources.jar: org/apache/solr/util/RandomForceMergePolicy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.util;

import org.apache.lucene.index.ForceMergePolicy;
import org.apache.lucene.index.MergePolicy;
import org.apache.lucene.util.LuceneTestCase;

/**
 * A {@link MergePolicy} with a no-arg constructor that proxies to a
 * {@link ForceMergePolicy} wrapped instance retrieved from
 * {@link LuceneTestCase#newMergePolicy}.
 * Solr tests utilizing the Lucene randomized test framework can refer 
 * to this class in solrconfig.xml to get a fully randomized merge policy
 * that only returns forced merges.
 */
public final class RandomForceMergePolicy extends RandomMergePolicy {

  public RandomForceMergePolicy() {
    super(new ForceMergePolicy(LuceneTestCase.newMergePolicy()));
  }

}

==> solr-test-framework-9.0.0-sources.jar: org/apache/solr/util/RandomForceMergePolicy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.util;

import org.apache.lucene.index.ForceMergePolicy;
import org.apache.lucene.index.MergePolicy;
import org.apache.lucene.util.LuceneTestCase;

/**
 * A {@link MergePolicy} with a no-arg constructor that proxies to a {@link ForceMergePolicy}
 * wrapped instance retrieved from {@link LuceneTestCase#newMergePolicy}. Solr tests utilizing the
 * Lucene randomized test framework can refer to this class in solrconfig.xml to get a fully
 * randomized merge policy that only returns forced merges.
 */
public final class RandomForceMergePolicy extends RandomMergePolicy {

  public RandomForceMergePolicy() {
    super(new ForceMergePolicy(LuceneTestCase.newMergePolicy()));
  }
}
